//
//  Examples.swift
//  SwiftUIExample
//
//  Created by Hiroki Kato on 2021/01/04.
//

import SwiftUI

struct Examples: View {
    @Environment(\.horizontalSizeClass) var horizontalSizeClass

    @State var showNavigation = false
    @State var showNavigationWithToolbar = false
    @State var showNavigationWithBottomToolbar = false

    var body: some View {
        NavigationView {
            List {
                Group {
                    Section(header: Text("UIの表示を司るView")) {
                        NavigationLink("SimpleView", destination: SimpleView())
                    }
                }
                Group {
                    Section(header: Text("Stackでレイアウト")) {
                        NavigationLink("StackLayout", destination: StackLayout())
                    }
                    Section(header: Text("画面の遷移はナビゲーション")) {
                        Button("Navigation") {
                            showNavigation = true
                        }.sheet(isPresented: $showNavigation, content: {
                            Navigation()
                                .navigationBarHidden(true)
                        })
                        Button("NavigationWithToolbar") {
                            showNavigationWithToolbar = true
                        }.sheet(isPresented: $showNavigationWithToolbar, content: {
                            NavigationWithToolbar()
                                .navigationBarHidden(true)
                        })
                        Button("NavigationWithBottomToolbar") {
                            showNavigationWithBottomToolbar = true
                        }.sheet(isPresented: $showNavigationWithBottomToolbar, content: {
                            NavigationWithBottomToolbar()
                                .navigationBarHidden(true)
                        })
                    }
                    Section(header: Text("画面を切り替えるタブ")) {
                        NavigationLink("Tab", destination: Tab())
                        NavigationLink("Page", destination: Page())
                    }
                    Section(header: Text("一時的に表示するためのモーダル")) {
                        NavigationLink("Modal", destination: Modal())
                    }
                }
                Group {
                    Section(header: Text("Viewに閉じた状態を表すState")) {
                        NavigationLink("Counter", destination: Counter())
                        NavigationLink("CounterWithBinding", destination: CounterWithBinding())
                    }
                    Section(header: Text("複雑な状態を表すObservableObject")) {
                        NavigationLink("ClockView", destination: ClockView())
                    }
                }
                Group {
                    Section(header: Text("Listでリスト表示")) {
                        NavigationLink("StaticList", destination: StaticList())
                        NavigationLink("DynamicList", destination: DynamicList())
                    }
                    Section(header: Text("LazyVGridでグリッド表示")) {
                        NavigationLink("Grid", destination: Grid())
                    }
                    Section(header: Text("LazyVStackでさらに複雑な表示")) {
                        NavigationLink("LazyStack", destination: LazyStack())
                    }
                }
                Group {
                    Section(header: Text("AppStorageでアプリの設定")) {
                        NavigationLink("AppSettings", destination: AppSettings())
                    }
                    Section(header: Text("SceneStorageでアプリの復元")) {
                        NavigationLink("Restoration", destination: Restoration())
                    }
                }
                Group {
                    Section(header: Text("ビューをライブラリに追加する")) {
                        NavigationLink("RoundedCornerText", destination: RoundedCornerText(content: "Hello, World!"))
                    }
                    Section(header: Text("モディファイアをライブラリに追加する")) {
                        NavigationLink("RoundedCornerModifier", destination: RoundedCornerModifier())
                    }
                }
            }
            .listStyle(GroupedListStyle())
            .navigationTitle("Examples")
        }
    }
}

struct Examples_Previews: PreviewProvider {
    static var previews: some View {
        Examples()
    }
}
