//
//  ColorPickerViewController.swift
//  UIKitExample
//
//  Created by Yutaro Muta on 2020/12/07.
//

import UIKit

class ColorPickerViewController: UIViewController {

    private let previewView: UIImageView

    override init(nibName nibNameOrNil: String!, bundle nibBundleOrNil: Bundle!) {
        previewView = UIImageView()
        super.init(nibName: nil, bundle: nil)
        view.backgroundColor = .systemBackground
        let button = UIButton(primaryAction: .init(handler: { [weak self] _ in
            let colorPickerViewController = UIColorPickerViewController()
            colorPickerViewController.delegate = self
            self?.present(colorPickerViewController, animated: true, completion: nil)
        }))
        button.setTitle("Open UIColorPickerViewController", for: .normal)
        let stackView = UIStackView(arrangedSubviews: [previewView, button])
        stackView.axis = .vertical
        view.addSubview(stackView)
        stackView.translatesAutoresizingMaskIntoConstraints = false
        NSLayoutConstraint.activate([
            stackView.leadingAnchor.constraint(equalTo: view.leadingAnchor),
            stackView.trailingAnchor.constraint(equalTo: view.trailingAnchor),
            stackView.topAnchor.constraint(equalTo: view.topAnchor),
            stackView.bottomAnchor.constraint(equalTo: view.bottomAnchor),
        ])
    }

    convenience init() {
        self.init(nibName: nil, bundle: nil)
    }

    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
}

extension ColorPickerViewController: UIColorPickerViewControllerDelegate {
    func colorPickerViewControllerDidSelectColor(_ viewController: UIColorPickerViewController) {
        let color = viewController.selectedColor
        previewView.image = UIImage.colored(color, size: previewView.bounds.size)
    }
}

extension UIImage {
    static func colored(_ color: UIColor, size: CGSize) -> UIImage {
        UIGraphicsBeginImageContextWithOptions(size, true, 0)
        defer { UIGraphicsEndImageContext() }

        color.set()
        UIGraphicsGetCurrentContext()!.fill(CGRect(x: 0, y: 0, width: size.width, height: size.height))

        return UIGraphicsGetImageFromCurrentImageContext()!
    }
}
