//
//  MenuViewController.swift
//  UIKitExample
//
//  Created by Yutaro Muta on 2021/01/01.
//

import UIKit

class MenuViewController: UIViewController {

    override init(nibName nibNameOrNil: String!, bundle nibBundleOrNil: Bundle!) {
        super.init(nibName: nibNameOrNil, bundle: nibBundleOrNil)
        view.backgroundColor = .systemBackground
        let barButtonItem = UIBarButtonItem(
            image: UIImage(systemName: "ellipsis.circle"),
            style: .plain,
            target: self,
            action: #selector(tapAction)
        )
        barButtonItem.menu = UIMenu(
            title: "",
            children: [
                UIAction(title: "Option 1",
                         handler: { print($0) }),
                UIAction(title: "Option 2",
                         handler: { print($0) }),
            ]
        )
        navigationItem.rightBarButtonItem = barButtonItem

        let button = UIButton()
        button.setTitleColor(.link, for: .normal)
        button.setTitle("Menu Button", for: .normal)
        button.showsMenuAsPrimaryAction = true
        button.menu = UIMenu(
            title: "",
            children: [
                UIMenu(title: "",
                       options: .displayInline,
                       children: [
                        UIAction(title: "Static Item 1",
                                 handler: { print($0) }),
                        UIAction(title: "Static Item 2",
                                 handler: { print($0) })]),
                UIDeferredMenuElement { completion in
                    DispatchQueue.main.asyncAfter(deadline: .now() + 3) {
                        completion([UIMenu(
                            title: "",
                            options: .displayInline,
                            children: [
                                UIAction(title: "Dynamic Item",
                                         handler: { print($0) })]
                        )])
                    }
                }
            ]
        )
        view.addSubview(button)
        button.translatesAutoresizingMaskIntoConstraints = false
        NSLayoutConstraint.activate([
            button.centerYAnchor.constraint(equalTo: view.centerYAnchor),
            button.centerXAnchor.constraint(equalTo: view.centerXAnchor),
        ])
    }

    convenience init() {
        self.init(nibName: nil, bundle: nil)
    }

    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }

    @objc func tapAction() {
        print(#function)
    }
}
