//
//  StaticWidget.swift
//  ExampleWidget
//
//  Created by Yutaro Muta on 2020/12/06.
//

import WidgetKit
import SwiftUI

struct StaticProvider: TimelineProvider {
    func placeholder(in context: Context) -> Entry {
        Entry(date: Date(),
              relevance: nil,
              devices: Device.iOSDevices)
    }

    func getSnapshot(in context: Context,
                     completion: @escaping (Entry) -> Void) {
        let entry = Entry(date: Date(),
                          relevance: nil,
                          devices: Device.iOSDevices)
        completion(entry)
    }

    func getTimeline(in context: Context,
                     completion: @escaping (Timeline<Entry>) -> Void) {
        var entries: [Entry] = []
        let currentDate = Date()
        let devices = Device.all.shuffled()
        switch context.family {
        case .systemSmall:
            let currentDate = Date()
            let devices = Device.all.shuffled()
            for hourOffset in 0 ..< devices.count {
                let entryDate = Calendar.current.date(byAdding: .minute, value: hourOffset, to: currentDate)!
                let device = devices[hourOffset]
                let entry = Entry(
                    date: entryDate,
                    relevance: .init(score: device.os.score),
                    devices: [device]
                )
                entries.append(entry)
            }
        case .systemMedium:
            for hourOffset in 0 ..< devices.count - 1 {
                let entryDate = Calendar.current.date(byAdding: .minute, value: hourOffset, to: currentDate)!
                let devices = [devices[hourOffset], devices[hourOffset + 1]]
                let relevance = TimelineEntryRelevance(score: devices.reduce(into: 0, { $0 += $1.os.score }))
                let entry = Entry(date: entryDate,
                                  relevance: relevance,
                                  devices: devices)
                entries.append(entry)
            }
        case .systemLarge:
            for hourOffset in 0 ..< devices.count - 2 {
                let entryDate = Calendar.current.date(byAdding: .minute, value: hourOffset, to: currentDate)!
                let devices = [devices[hourOffset], devices[hourOffset + 1], devices[hourOffset + 2]]
                let relevance = TimelineEntryRelevance(score: devices.reduce(into: 0, { $0 += $1.os.score }))
                let entry = Entry(date: entryDate,
                                  relevance: relevance,
                                  devices: devices)
                entries.append(entry)
            }
        default:
            break
        }

        let timeline = Timeline(entries: entries, policy: .atEnd)
        completion(timeline)
    }
}

struct StaticWidget: Widget {
    let kind: String = "StaticWidget"

    var body: some WidgetConfiguration {
        StaticConfiguration(
            kind: kind,
            provider: StaticProvider(),
            content:  { entry in
                WidgetEntryView(devices: entry.devices)
            }
        )
        .configurationDisplayName("Apple devices")
        .description("Show Apple devices' icon")
    }
}

struct StaticWidget_Previews: PreviewProvider {
    static var previews: some View {
        WidgetEntryView(devices: Device.all)
            .previewContext(WidgetPreviewContext(family: .systemSmall))
    }
}
