//
//  ContentView.swift
//  WidgetExample
//
//  Created by Yutaro Muta on 2020/12/06.
//

import SwiftUI

struct ContentView: View {
    @State var device: Device?
    var devices: [Device] = Device.all

    var body: some View {
        List {
            ForEach(devices) { device in
                Button {
                    self.device = device
                } label: {
                    HStack {
                        device.image
                            .foregroundColor(device.color)
                        Text(device.model)
                    }
                }
            }
        }
        .sheet(item: $device) {
            DeviceView(device: $0)
        }
        .onOpenURL { url in
            device = Device(from: url)
        }
    }
}

struct DeviceView: View {
    var device: Device?

    var body: some View {
        if let device = device {
            VStack {
                SingleDeviceView(device: device)
                Text(device.model)
            }
        } else {
            Text("No device")
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
